==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/pl/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "w tym kwartale",
	"field-quarter-short-relative+1": "w przyszłym kwartale",
	"field-tue-relative+-1": "w zeszły wtorek",
	"field-year": "rok",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "w tę środę",
	"field-wed-relative+1": "w przyszłą środę",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuta",
	"field-tue-narrow-relative+0": "w ten wtorek",
	"field-tue-narrow-relative+1": "w przyszły wtorek",
	"field-thu-short-relative+0": "w ten czwartek",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "w przyszły czwartek",
	"field-day-relative+0": "dzisiaj",
	"field-day-relative+1": "jutro",
	"field-day-relative+2": "pojutrze",
	"field-wed-narrow-relative+-1": "w zeszłą środę",
	"field-year-narrow": "r.",
	"field-tue-relative+0": "w ten wtorek",
	"field-tue-relative+1": "w przyszły wtorek",
	"field-second-short": "sek.",
	"dateFormatItem-yyyyMM": "MM.y G",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "w tym tygodniu",
	"field-month-relative+0": "w tym miesiącu",
	"field-week-relative+1": "w przyszłym tygodniu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"field-sun-narrow-relative+0": "w tę niedzielę",
	"field-mon-short-relative+0": "w ten poniedziałek",
	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
	"field-mon-short-relative+1": "w przyszły poniedziałek",
	"field-second-relative+0": "teraz",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "mies.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d.MM.y G",
	"field-day": "dzień",
	"field-year-relative+-1": "w zeszłym roku",
	"field-sat-short-relative+-1": "w zeszłą sobotę",
	"field-hour-relative+0": "ta godzina",
	"dateFormatItem-yyyyMEd": "E, d.MM.y G",
	"field-wed-relative+-1": "w zeszłą środę",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
	"field-second": "sekunda",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "kwartał",
	"field-week-short": "tydz.",
	"field-tue-short-relative+0": "w ten wtorek",
	"field-tue-short-relative+1": "w przyszły wtorek",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "miesiąc",
	"field-day-narrow": "dzień",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "rano / po południu / wieczorem",
	"field-sat-short-relative+0": "w tę sobotę",
	"field-sat-short-relative+1": "w przyszłą sobotę",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"field-year-short": "r.",
	"field-quarter-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-sat-relative+-1": "w zeszłą sobotę",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-Md": "d.MM",
	"field-hour": "godzina",
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "kw.",
	"field-sat-narrow-relative+0": "w tę sobotę",
	"field-fri-relative+0": "w ten piątek",
	"field-sat-narrow-relative+1": "w przyszłą sobotę",
	"field-fri-relative+1": "w przyszły piątek",
	"field-sun-short-relative+0": "w tę niedzielę",
	"field-sun-short-relative+1": "w przyszłą niedzielę",
	"field-week-relative+-1": "w zeszłym tygodniu",
	"field-quarter-short-relative+-1": "w zeszłym kwartale",
	"field-quarter-relative+0": "w tym kwartale",
	"field-minute-relative+0": "ta minuta",
	"field-quarter-relative+1": "w przyszłym kwartale",
	"field-wed-short-relative+-1": "w zeszłą środę",
	"dateFormat-short": "dd.MM.y G",
	"field-thu-short-relative+-1": "w zeszły czwartek",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "w zeszły czwartek",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "w zeszły wtorek",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "w tę środę",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "w przyszłą środę",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"dateTimeFormat-full": "{1}, {0}",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "dzień tygodnia",
	"field-quarter-narrow-relative+0": "w tym kwartale",
	"field-sat-relative+0": "w tę sobotę",
	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
	"dateFormatItem-h": "hh a",
	"field-sat-relative+1": "w przyszłą sobotę",
	"dateFormatItem-MEd": "E, d.MM",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "w ten czwartek",
	"field-thu-narrow-relative+1": "w przyszły czwartek",
	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
	"field-mon-short-relative+-1": "w zeszły poniedziałek",
	"field-thu-relative+0": "w ten czwartek",
	"field-thu-relative+1": "w przyszły czwartek",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "w zeszły piątek",
	"field-thu-relative+-1": "w zeszły czwartek",
	"field-week": "tydzień",
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "w tę środę",
	"field-wed-narrow-relative+1": "w przyszłą środę",
	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-fri-short-relative+0": "w ten piątek",
	"field-fri-short-relative+1": "w przyszły piątek",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "godz.",
	"field-month-narrow": "mc",
	"field-hour-narrow": "g.",
	"field-fri-narrow-relative+-1": "w zeszły piątek",
	"field-year-relative+0": "w tym roku",
	"field-year-relative+1": "w przyszłym roku",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-tue-short-relative+-1": "w zeszły wtorek",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "w ten poniedziałek",
	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
	"field-zone": "strefa czasowa",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-quarter-narrow": "kw.",
	"field-sun-short-relative+-1": "w zeszłą niedzielę",
	"field-day-relative+-1": "wczoraj",
	"field-day-relative+-2": "przedwczoraj",
	"field-sun-relative+0": "w tę niedzielę",
	"dateFormatItem-MMdd": "d.MM",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dzień",
	"field-week-narrow": "tydz.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "w ten piątek",
	"field-fri-narrow-relative+1": "w przyszły piątek"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/pl/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "w tym kwartale",
	"field-quarter-short-relative+1": "w przyszłym kwartale",
	"field-tue-relative+-1": "w zeszły wtorek",
	"field-year": "rok",
	"field-wed-relative+0": "w tę środę",
	"field-wed-relative+1": "w przyszłą środę",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "w zeszłym mies.",
	"field-tue-narrow-relative+0": "w ten wtorek",
	"field-tue-narrow-relative+1": "w przyszły wtorek",
	"field-thu-short-relative+0": "w ten czwartek",
	"dateTimeFormat-short": "{1}, {0}",
	"field-day-relative+0": "dzisiaj",
	"field-day-short-relative+-2": "przedwczoraj",
	"field-thu-short-relative+1": "w przyszły czwartek",
	"field-day-relative+1": "jutro",
	"field-week-narrow-relative+0": "w tym tyg.",
	"field-day-relative+2": "pojutrze",
	"field-week-narrow-relative+1": "w przyszłym tyg.",
	"field-wed-narrow-relative+-1": "w zeszłą środę",
	"field-year-narrow": "r.",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "w tym roku",
	"field-tue-relative+0": "w ten wtorek",
	"field-year-narrow-relative+1": "w przyszłym roku",
	"field-tue-relative+1": "w przyszły wtorek",
	"field-weekdayOfMonth": "dzień miesiąca",
	"field-second-short": "sek.",
	"dateFormatItem-yyyyMM": "MM.y G",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "dz. mies.",
	"field-week-relative+0": "w tym tygodniu",
	"field-month-relative+0": "w tym miesiącu",
	"field-week-relative+1": "w przyszłym tygodniu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"field-sun-narrow-relative+0": "w tę niedzielę",
	"field-mon-short-relative+0": "w ten poniedziałek",
	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
	"field-mon-short-relative+1": "w przyszły poniedziałek",
	"field-second-relative+0": "teraz",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "tydzień miesiąca",
	"field-month-short": "mies.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d.MM.y G",
	"field-day": "dzień",
	"field-dayOfYear-short": "dz. roku",
	"field-year-relative+-1": "w zeszłym roku",
	"field-sat-short-relative+-1": "w zeszłą sobotę",
	"field-hour-relative+0": "ta godzina",
	"dateFormatItem-yyyyMEd": "E, d.MM.y G",
	"field-wed-relative+-1": "w zeszłą środę",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
	"field-second": "sekunda",
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "kwartał",
	"field-week-short": "tydz.",
	"field-day-narrow-relative+0": "dziś",
	"field-day-narrow-relative+1": "jutro",
	"field-day-narrow-relative+2": "pojutrze",
	"field-tue-short-relative+0": "w ten wtorek",
	"field-tue-short-relative+1": "w przyszły wtorek",
	"field-month-short-relative+-1": "w zeszłym mies.",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-month": "miesiąc",
	"field-day-narrow": "d.",
	"field-minute-short": "min",
	"field-dayperiod": "rano / po południu / wieczorem",
	"field-sat-short-relative+0": "w tę sobotę",
	"field-sat-short-relative+1": "w przyszłą sobotę",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-second-narrow": "s",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"field-day-narrow-relative+-1": "wcz.",
	"field-year-short": "r.",
	"field-day-narrow-relative+-2": "przedwczoraj",
	"field-quarter-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"field-dayperiod-narrow": "rano / po poł. / wiecz.",
	"field-week-narrow-relative+-1": "w zeszłym tyg.",
	"field-dayOfYear": "dzień roku",
	"field-sat-relative+-1": "w zeszłą sobotę",
	"dateTimeFormat-long": "{1}, {0}",
	"dateFormatItem-Md": "d.MM",
	"field-hour": "godzina",
	"dateFormat-full": "EEEE, d MMMM y G",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"field-quarter-short": "kw.",
	"field-sat-narrow-relative+0": "w tę sobotę",
	"field-fri-relative+0": "w ten piątek",
	"field-sat-narrow-relative+1": "w przyszłą sobotę",
	"field-fri-relative+1": "w przyszły piątek",
	"field-month-narrow-relative+0": "w tym mies.",
	"field-month-narrow-relative+1": "w przyszłym mies.",
	"field-sun-short-relative+0": "w tę niedzielę",
	"field-sun-short-relative+1": "w przyszłą niedzielę",
	"field-week-relative+-1": "w zeszłym tygodniu",
	"field-quarter-short-relative+-1": "w zeszłym kwartale",
	"field-quarter-relative+0": "w tym kwartale",
	"field-minute-relative+0": "ta minuta",
	"field-quarter-relative+1": "w przyszłym kwartale",
	"field-wed-short-relative+-1": "w zeszłą środę",
	"dateFormat-short": "dd.MM.y G",
	"field-year-narrow-relative+-1": "w zeszłym roku",
	"field-thu-short-relative+-1": "w zeszły czwartek",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "w zeszły czwartek",
	"field-tue-narrow-relative+-1": "w zeszły wtorek",
	"field-weekOfMonth-short": "tydz. mies.",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "w tę środę",
	"field-wed-short-relative+1": "w przyszłą środę",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"dateTimeFormat-full": "{1}, {0}",
	"dateFormatItem-hm": "hh:mm a",
	"field-weekday": "dzień tygodnia",
	"field-quarter-narrow-relative+0": "w tym kwartale",
	"field-sat-relative+0": "w tę sobotę",
	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
	"dateFormatItem-h": "hh a",
	"field-day-short-relative+2": "pojutrze",
	"field-sat-relative+1": "w przyszłą sobotę",
	"field-week-short-relative+0": "w tym tyg.",
	"field-week-short-relative+1": "w przyszłym tyg.",
	"field-dayOfYear-narrow": "dz. r.",
	"field-month-short-relative+0": "w tym mies.",
	"field-month-short-relative+1": "w przyszłym mies.",
	"field-weekdayOfMonth-short": "dzień mies.",
	"dateFormatItem-MEd": "E, d.MM",
	"field-zone-narrow": "str. czas.",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "w ten czwartek",
	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
	"field-mon-short-relative+-1": "w zeszły poniedziałek",
	"field-thu-narrow-relative+1": "w przyszły czwartek",
	"field-thu-relative+0": "w ten czwartek",
	"field-thu-relative+1": "w przyszły czwartek",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "w zeszły piątek",
	"field-thu-relative+-1": "w zeszły czwartek",
	"field-week": "tydzień",
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "w tę środę",
	"field-wed-narrow-relative+1": "w przyszłą środę",
	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
	"field-year-short-relative+0": "w tym roku",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"field-dayperiod-short": "rano / po południu / wieczorem",
	"field-year-short-relative+1": "w przyszłym roku",
	"field-fri-short-relative+0": "w ten piątek",
	"field-fri-short-relative+1": "w przyszły piątek",
	"field-week-short-relative+-1": "w zeszłym tyg.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "godz.",
	"field-zone-short": "str. czasowa",
	"field-month-narrow": "mc",
	"field-hour-narrow": "g.",
	"field-fri-narrow-relative+-1": "w zeszły piątek",
	"field-year-relative+0": "w tym roku",
	"field-year-relative+1": "w przyszłym roku",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-tue-short-relative+-1": "w zeszły wtorek",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "w ten poniedziałek",
	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
	"field-year-short-relative+-1": "w zeszłym roku",
	"field-zone": "strefa czasowa",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "tydz. mies.",
	"field-weekday-narrow": "dz. tyg.",
	"field-quarter-narrow": "kw.",
	"field-sun-short-relative+-1": "w zeszłą niedzielę",
	"field-day-relative+-1": "wczoraj",
	"field-day-relative+-2": "przedwczoraj",
	"field-weekday-short": "dzień tyg.",
	"field-sun-relative+0": "w tę niedzielę",
	"dateFormatItem-MMdd": "d.MM",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "dz.",
	"field-week-narrow": "tydz.",
	"field-era": "era",
	"field-fri-narrow-relative+0": "w ten piątek",
	"field-fri-narrow-relative+1": "w przyszły piątek"
}
//end v1.x content
);
